==> mitre-assistant-0.0.18.crate: mitre-assistant-0.0.18/README.md <==
[![Github Downloads](https://img.shields.io/github/downloads/dfirence/mitre-assistant/total)]()
[![Github Stars](https://img.shields.io/github/stars/dfirence/mitre-assistant)]()


<div id="title"align="center">
    <h1>#MITRE-ASSISTANT</h1>
    <p>A More Flexible, Useful and Cooler Mitre ATT&CK Client</p>
</div>

<br/>

<div id="docs" align="center">
    <h1><a href="https://dfirence.github.io/mitre-assistant/" target="_blank" norelopener><strong>docs-wiki-mitre-assistant</strong></a></h1>
</div>

<br/>

<img src="https://user-images.githubusercontent.com/11415591/97825504-d802e680-1c8c-11eb-890a-bbee6e00e1a2.jpeg" />

<hr/>
<br/>

<img src="https://user-images.githubusercontent.com/11415591/97825506-d802e680-1c8c-11eb-8ef4-001673a59529.jpeg" />

<hr/>
<br/>

<img src="https://user-images.githubusercontent.com/11415591/90009693-8a1daa00-dc6c-11ea-87c7-968da8f400e8.png" />

<hr />
<br/>

<img src="https://user-images.githubusercontent.com/11415591/93018273-839c8e00-f59c-11ea-9ee0-2490b870fbf0.png" />

<hr />

<br/>

## W.I.P - Status
- [x] Mitre Enterprise Matrix
    - [x] V6 CTI Legacy Support
    - [x] V7 CTI Beta
    - [x] V8 CTI Merge With PRE ATT&CK
    - [x] V9 CTI
- [ ] Mitre Mobile Matrix
- [ ] Mitre Navigator JSON
    - [x] Legacy Version
    - [x] Modern Version with Subtechniques
    - [x] Ingestion
    - [ ] Exports to Navigator Format
- [x] Linux - 64bit
- [x] MacOS - 64bit
- [x] Windows - 64bit
- [x] Data Interchange Format
   - [x] CSV
   - [x] JSON
- [ ] Exports
   - [x] CSV
   - [x] JSON
   - [ ] Rich Web

<hr>

<br/>
<br/>


# References
|SOURCE|URL|
|------|---|
|Mitre CTI Github|[LINK](https://github.com/mitre/cti/blob/master/USAGE.md#working-with-deprecated-and-revoked-objects)|

<br/>
<br/>

==> mitre-assistant-0.0.19.crate: mitre-assistant-0.0.19/README.md <==
[![Github Downloads](https://img.shields.io/github/downloads/dfirence/mitre-assistant/total)]()
[![Github Stars](https://img.shields.io/github/stars/dfirence/mitre-assistant)]()


<div id="title"align="center">
    <img src="https://user-images.githubusercontent.com/11415591/117546884-b3e8df00-affa-11eb-9db1-d03a99c8ebed.png"
        alt="malogo"
    />
    <br />
    <h3>A More Flexible, Useful and Cooler Mitre ATT&CK Client</h3>
</div>

<br/>
<hr />
<div id="docs" align="center">
    <h1><a href="https://dfirence.github.io/mitre-assistant/" target="_blank" norelopener><strong>docs-wiki-mitre-assistant</strong></a></h1>
</div>

<br/>

<img src="https://user-images.githubusercontent.com/11415591/97825504-d802e680-1c8c-11eb-890a-bbee6e00e1a2.jpeg" />

<hr/>
<br/>

<img src="https://user-images.githubusercontent.com/11415591/97825506-d802e680-1c8c-11eb-8ef4-001673a59529.jpeg" />

<hr/>
<br/>

<img src="https://user-images.githubusercontent.com/11415591/90009693-8a1daa00-dc6c-11ea-87c7-968da8f400e8.png" />

<hr />
<br/>

<img src="https://user-images.githubusercontent.com/11415591/93018273-839c8e00-f59c-11ea-9ee0-2490b870fbf0.png" />

<hr />

<br/>

## W.I.P - Status
- [x] Mitre Enterprise Matrix
    - [x] V6 CTI Legacy Support
    - [x] V7 CTI Beta
    - [x] V8 CTI Merge With PRE ATT&CK
    - [x] V9 CTI
- [ ] Mitre Mobile Matrix
- [ ] Mitre Navigator JSON
    - [x] Legacy Version
    - [x] Modern Version with Subtechniques
    - [x] Ingestion
    - [ ] Exports to Navigator Format
- [x] Linux - 64bit
- [x] MacOS - 64bit
- [x] Windows - 64bit
- [x] Data Interchange Format
   - [x] CSV
   - [x] JSON
- [ ] Exports
   - [x] CSV
   - [x] JSON
   - [ ] Rich Web

<hr>

<br/>
<br/>


# References
|SOURCE|URL|
|------|---|
|Mitre CTI Github|[LINK](https://github.com/mitre/cti/blob/master/USAGE.md#working-with-deprecated-and-revoked-objects)|

<br/>
<br/>
